@@ -168,7 +168,7 @@ class BaseModelMixin:
         return items
 
     @classmethod
-    def to_dict_field_filter(cls, field, *args, **kwargs):
+    def to_dict_field_filter(cls, field):
         """
         to_dict callback.
         If return false, the field will not be returned.
@@ -178,10 +178,10 @@ class BaseModelMixin:
         return True
 
     @classmethod
-    def get_columns_json(cls, json_data):
+    def get_columns_json(cls, data):
         """
         Get the data corresponding to the column.
-        :param json_data::
+        :param data::
         :return:
         """
         json = {}
@@ -195,8 +195,8 @@ class BaseModelMixin:
 
         for col in cls.get_columns():
             field = cls.get_column_field(col)  # col.key
-            if field in json_data and field not in auto_fields and not col.info.get('auto', False):
-                value = json_data.get(field)
+            if (field in data) and (field not in auto_fields) and (not col.info.get('auto', False)):
+                value = data.get(field)
                 if col.nullable is False:
                     if not (value is None or (is_str(value) and value.strip() == "")):
                         json[field] = value
@@ -207,31 +207,31 @@ class BaseModelMixin:
 
     # -------------------------------------------add-------------------------------------------
     @classmethod
-    def check_add_data(cls, json_data):
+    def check_add_data(cls, data):
         """
         Check the the added json data.
         --validate the json data
         --check unique
         If the check result is not True, the adding process will be terminated and the check result will be returned to the client.
 
-        :param json_data:  The data to be added
+        :param data:  The data to be added
         :return: True|Error Message
         """
-        if not is_dict(json_data):
-            if json_data:
-                return json_data
+        if not is_dict(data):
+            if data:
+                return data
             return res_status_codes.bad_request
-        return cls._check_unique(json_data)
+        return cls._check_unique(data)
 
     @classmethod
-    def add_db(cls, json_data):
+    def add_db(cls, data):
         """
         Add the data to the db.
 
-        :param json_data:
+        :param data:
         :return:
         """
-        instance = create_instance(cls, json_data)
+        instance = create_instance(cls, data)
         with db_session() as session:
             session.add(instance)
         return instance
@@ -249,16 +249,19 @@ class BaseModelMixin:
             return
         if with_relationship is True:
             with db_session() as session:
+                ins_list = []
                 for data_item in items:
-                    instance = create_instance(cls, data_item)
-                    session.add(instance)
+                    ins_list.append(create_instance(cls, data_item))
+                    # instance = create_instance(cls, data_item)
+                    # session.add(instance)
+                session.add_all(ins_list)
         else:
             with db_session() as session:
                 session.bulk_insert_mappings(cls, items)
 
     # -------------------------------------------update-------------------------------------------
     @classmethod
-    def check_update_data(cls, json_data):
+    def check_update_data(cls, data):
         """
         Check the the updated json data.
         --validate the json data
@@ -266,37 +269,38 @@ class BaseModelMixin:
         --check unique
         If the check result is not True, the update process will be terminated and the check result will be returned to the client.
 
-        :param json_data: The updated json data
+        :param data: The updated json data
         :return:
         """
-        if not is_dict(json_data):
-            if json_data:
-                return json_data
+        if not is_dict(data):
+            if data:
+                return data
             return res_status_codes.bad_request
 
-        exist = cls._check_exist(json_data)
+        exist = cls._check_exist(data)
         if exist is not True:
             return exist
-        return cls._check_unique(json_data)
+        return cls._check_unique(data)
 
     @classmethod
-    def update_db(cls, json_data):
+    def update_db(cls, data):
         """
         Update the data to the db.
         Only the fields in json will be updated
 
-        :param json_data:
+        :param data:
         :return:
         """
-        pk_value = cls._get_pk_value(json_data)
+        pk_value = cls._get_pk_value(data)
         instance = cls.query_by_pk(pk_value)
-        with db_session() as session:
-            # Only the fields in json will be updated
-            for field in cls.get_columns_json(json_data):
-                setattr(instance, field, json_data.get(field))
-            relationships = create_relationships(cls, json_data)
-            for field in relationships:
-                setattr(instance, field, relationships[field])
+        if instance:
+            with db_session() as session:
+                # Only the fields in json will be updated
+                for field in cls.get_columns_json(data):
+                    setattr(instance, field, data.get(field))
+                relationships = create_relationships(cls, data)
+                for field in relationships:
+                    setattr(instance, field, relationships[field])
         return instance
 
     @classmethod
@@ -340,9 +344,9 @@ class BaseModelMixin:
             return res_status_codes.db_data_not_found
 
         primary_field = cls.get_primary_field()
-        json_data = {primary_field: pk_value}
+        data = {primary_field: pk_value}
 
-        return cls._check_exist(json_data)
+        return cls._check_exist(data)
 
     @classmethod
     def delete_db(cls, pk_value):
@@ -408,13 +412,13 @@ class BaseModelMixin:
         return cls.get_primary_column()
 
     @classmethod
-    def query_by_unique_key(cls, json_data):
+    def query_by_unique_key(cls, data):
         """
         Query data by the unique values.
         --If exist,returns the instance.
         --Otherwise,returns None
 
-        :param json_data:
+        :param data:
         :return:
         """
         cols = cls.get_unique_columns()
@@ -424,7 +428,7 @@ class BaseModelMixin:
         ors = []
         for col in cols:
             field = cls.get_column_field(col)  # col.key
-            value = json_data.get(field)
+            value = data.get(field)
             if value is not None:  # maybe 0
                 ors.append(field + "='" + str(value).strip() + "'")
 
@@ -524,42 +528,42 @@ class BaseModelMixin:
 
     # -------------------------------------------check-------------------------------------------
     @classmethod
-    def _get_pk_value(cls, json_data):
+    def _get_pk_value(cls, data):
         """
         Get the primary key value from the json data
-        :param json_data:
+        :param data:
         :return:
         """
         primary_field = cls.get_primary_field()
         if primary_field:
-            return json_data.get(primary_field)
+            return data.get(primary_field)
 
     @classmethod
-    def _check_exist(cls, json_data):
+    def _check_exist(cls, data):
         """
         Check whether the data exists
         Return True if exists, else return not found code
-        :param json_data:
+        :param data:
         :return:
         """
-        pk_value = cls._get_pk_value(json_data)
+        pk_value = cls._get_pk_value(data)
         if pk_value is not None and cls.query_by_pk(pk_value):
             return True
         return res_status_codes.db_data_not_found  # used to return to the client
 
     @classmethod
-    def _check_unique(cls, json_data):
+    def _check_unique(cls, data):
         """
         Check whether the data meets uniqueness constraints.
         If meets, returns True, otherwise returns exist code.
         """
-        result = cls.query_by_unique_key(json_data)
+        result = cls.query_by_unique_key(data)
 
         if result is None:
             return True
 
         primary_field = cls.get_primary_field()
-        pk_value = cls._get_pk_value(json_data)
+        pk_value = cls._get_pk_value(data)
         if pk_value is not None and pk_value == getattr(result, primary_field):
             return True
         return res_status_codes.db_data_already_exist  # used to return to the client
